# Calendar heatmaps from Pandas time series data
------------------------------------------------
[![PyPI version](https://badge.fury.io/py/calmap.svg)](https://badge.fury.io/py/calmap)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/calmap.svg)
[![Build Status](https://travis-ci.com/MarvinT/calmap.svg?branch=master)](https://travis-ci.com/MarvinT/calmap)
[![Coverage Status](https://coveralls.io/repos/github/MarvinT/calmap/badge.svg?branch=master)](https://coveralls.io/github/MarvinT/calmap?branch=master)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Downloads](https://pepy.tech/badge/calmap)](https://pepy.tech/project/calmap)

Plot [Pandas](http://pandas.pydata.org/) time series data sampled by day in
a heatmap per calendar year, similar to GitHub's contributions plot, using
[matplotlib](http://matplotlib.org/).

![alt text](https://pythonhosted.org/calmap/_images/index-2.png "Example calendar heatmap")

## Usage
--------

See the [documentation](https://pythonhosted.org/calmap).


## Installation
---------------

To install the latest release via PyPI using pip::

    pip install calmap
